Struct Hsv

#[repr(C)]
pub struct Hsv<T, A = Deg<T>> { /* private fields */ }
The HSV device-dependent polar color model

hsv-diagram

HSV is defined by a hue (base color), saturation (color richness) and value (color intensity). HSV is modeled as a cylinder, however the underlying space is conical. This causes some level of distortion and a degeneracy at S=0 or V=0. Thus, while easy to reason about, it is not good for perceptual uniformity. It does an okay job with averaging colors or doing other math, but prefer the CIE spaces for uniform gradients.

Hsv takes two type parameters: the cartesian channel scalar, and an angular channel scalar.

Hsv is in the same color space and encoding as the parent RGB space, it is merely a geometric transformation and distortion.

For an undistorted device-dependent polar color model, look at Hsi.

Implementations

Source

impl<T, A> Hsv<T, A>

pub fn new(hue: A, saturation: T, value: T) -> Self

Construct an Hsv instance from hue, saturation and value

pub fn color_cast<TOut, AOut>(&self) -> Hsv<TOut, AOut>

Convert the internal channel scalar format

pub fn hue(&self) -> A

Returns the hue scalar

pub fn saturation(&self) -> T

Returns the saturation scalar

pub fn value(&self) -> T

Returns the value scalar

pub fn hue_mut(&mut self) -> &mut A

Returns a mutable reference to the hue channel scalar

pub fn saturation_mut(&mut self) -> &mut T

Returns a mutable reference to the saturation channel scalar

pub fn value_mut(&mut self) -> &mut T

Returns a mutable reference to the value channel scalar

pub fn set_hue(&mut self, val: A)

Set the hue channel value

pub fn set_saturation(&mut self, val: T)

Set the saturation channel value

pub fn set_value(&mut self, val: T)

Set the value channel value