Struct Luv

#[repr(C)]
pub struct Luv<T, W> { /* private fields */ }
The CIELUV perceptually uniform device-independent color space

Luv is a perceptually uniform color space introduced by CIE at the same time as Lab. Luv is especially well suited for dealing with colored lighting computations, with the additive mixture of two lights falling along a line in its the chromaticity space. It is an extension to the previous CIE UVW space.

Like Lab, Luv has a polar representation: Lchuv.

Implementations

Source

impl<T, W> Luv<T, W>

pub fn new(L: T, u: T, v: T) -> Self

Construct a new Luv value with a named white point and channels.

Unlike new_with_whitepoint, new constructs a default instance of a UnitWhitePoint. It is only valid when W is a UnitWhitePoint.

Source

impl<T, W> Luv<T, W>
where T: FreeChannelScalar, W: WhitePoint<T>,

pub fn new_with_whitepoint(L: T, u: T, v: T, white_point: W) -> Self

Construct a new Luv value with a given white point and channels

pub fn color_cast<TOut>(&self) -> Luv<TOut, W>
where T: ChannelFormatCast<TOut>, TOut: FreeChannelScalar,

Convert the internal channel scalar format

pub fn L(&self) -> T

Returns the L lightness channel scalar

pub fn u(&self) -> T

Returns the u green-red channel scalar

pub fn v(&self) -> T

Returns the v blue-yellow channel scalar

pub fn L_mut(&mut self) -> &mut T

Returns a mutable reference to the L lightness channel scalar

pub fn u_mut(&mut self) -> &mut T

Returns a mutable reference to the u green-red channel scalar

pub fn v_mut(&mut self) -> &mut T

Returns a mutable reference to the v blue-yellow channel scalar

pub fn set_L(&mut self, val: T)

Set the L channel scalar

pub fn set_u(&mut self, val: T)

Set the u channel scalar

pub fn set_v(&mut self, val: T)

Set the v channel scalar

pub fn white_point(&self) -> &W

Returns a reference to the white point for the Lab color space

Source

impl<T, W> Luv<T, W>

pub fn from_xyz(from: &Xyz<T>, wp: W) -> Self

Construct a Luv value from an Xyz value and white point

pub fn to_xyz(&self) -> Xyz<T>

Construct an Xyz value from a Luv value

pub fn epsilon() -> T

Return the $\epsilon$ constant used in the Lab conversion

For a description of the value, visit BruceLindbloom.com.

pub fn kappa() -> T

Return the $\kappa$ constant used in the Lab conversion

For a description of the value, visit BruceLindbloom.com.