Struct Rgb

#[repr(C)]
pub struct Rgb<T> { /* private fields */ }
The Rgb device-dependent cartesian color model.

Rgb<T> has three primaries: red, green blue, which are always positive and in the normalized range [0, 1]. Rgb<T> accepts both integer and float components.

It is made to be efficient and easy to use in many different applications, and can be transmuted directly to a &[T; N].

Rgb is the base device dependent color space from which all others go through to convert, which can be converted to the other device dependent spaces or to the device independent CIE spaces directly. The color space of Rgb is not specified or assumed, it is up to you to not mix color spaces improperly or use an appropriate wrapper.

Examples:

use prisma::{Broadcast, HomogeneousColor, Lerp, Rgb};

let black = Rgb::broadcast(0.0f32);
let blue = Rgb::new(0, 0, 255u8);
// Convert blue to have float channels and compute the color halfway between blue and black
let blended = black.lerp(&blue.color_cast(), 0.5);

assert_eq!(blended, Rgb::new(0.0, 0.0, 0.5));

Implementations

Source

impl<T> Rgb<T>

pub fn new(red: T, green: T, blue: T) -> Self

Construct a new Rgb instance with the given channel values

pub fn color_cast<TOut>(&self) -> Rgb<TOut>

Convert the internal channel scalar format

pub fn red(&self) -> T

Returns the red channel scalar

pub fn green(&self) -> T

Returns the green channel scalar

pub fn blue(&self) -> T

Returns the blue channel scalar

pub fn red_mut(&mut self) -> &mut T

Returns a mutable reference to the red channel scalar

pub fn green_mut(&mut self) -> &mut T

Returns a mutable reference to the green channel scalar

pub fn blue_mut(&mut self) -> &mut T

Returns a mutable reference to the blue channel scalar

pub fn set_red(&mut self, val: T)

Set the red channel value

pub fn set_green(&mut self, val: T)

Set the green channel value

pub fn set_blue(&mut self, val: T)

Set the blue channel value

Source

impl<T> Rgb<T>

pub fn chromaticity_coordinates(&self) -> ChromaticityCoordinates<T>

Compute the ChromaticityCooridinates for an Rgb instance