#[repr(C)]pub struct Hsv<T, A = Deg<T>> { /* private fields */ }Expand description
The HSV device-dependent polar color model

HSV is defined by a hue (base color), saturation (color richness) and value (color intensity). HSV is modeled as a cylinder, however the underlying space is conical. This causes some level of distortion and a degeneracy at S=0 or V=0. Thus, while easy to reason about, it is not good for perceptual uniformity. It does an okay job with averaging colors or doing other math, but prefer the CIE spaces for uniform gradients.
Hsv takes two type parameters: the cartesian channel scalar, and an angular channel scalar.
Hsv is in the same color space and encoding as the parent RGB space, it is merely a geometric transformation and distortion.
For an undistorted device-dependent polar color model, look at Hsi.
Implementations
Sourceimpl<T, A> Hsv<T, A>where
T: PosNormalChannelScalar,
A: AngularChannelScalar,
impl<T, A> Hsv<T, A>where
T: PosNormalChannelScalar,
A: AngularChannelScalar,
Sourcepub fn new(hue: A, saturation: T, value: T) -> Self
pub fn new(hue: A, saturation: T, value: T) -> Self
Construct an Hsv instance from hue, saturation and value
Sourcepub fn color_cast<TOut, AOut>(&self) -> Hsv<TOut, AOut>where
T: ChannelFormatCast<TOut>,
A: ChannelFormatCast<AOut>,
AOut: AngularChannelScalar,
TOut: PosNormalChannelScalar,
pub fn color_cast<TOut, AOut>(&self) -> Hsv<TOut, AOut>where
T: ChannelFormatCast<TOut>,
A: ChannelFormatCast<AOut>,
AOut: AngularChannelScalar,
TOut: PosNormalChannelScalar,
Convert the internal channel scalar format
Sourcepub fn saturation(&self) -> T
pub fn saturation(&self) -> T
Returns the saturation scalar
Sourcepub fn saturation_mut(&mut self) -> &mut T
pub fn saturation_mut(&mut self) -> &mut T
Returns a mutable reference to the saturation channel scalar
Sourcepub fn set_saturation(&mut self, val: T)
pub fn set_saturation(&mut self, val: T)
Set the saturation channel value