#[repr(C)]pub struct Luv<T, W> { /* private fields */ }Expand description
The CIELUV perceptually uniform device-independent color space
Luv is a perceptually uniform color space introduced by CIE at the same time as Lab.
Luv is especially well suited for dealing with colored lighting computations, with the additive
mixture of two lights falling along a line in its the chromaticity space. It is an extension to
the previous CIE UVW space.
Like Lab, Luv has a polar representation: Lchuv.
Implementations
Sourceimpl<T, W> Luv<T, W>where
T: FreeChannelScalar,
W: UnitWhitePoint<T>,
impl<T, W> Luv<T, W>where
T: FreeChannelScalar,
W: UnitWhitePoint<T>,
Sourcepub fn new(L: T, u: T, v: T) -> Self
pub fn new(L: T, u: T, v: T) -> Self
Construct a new Luv value with a named white point and channels.
Unlike new_with_whitepoint, new constructs a default instance of a UnitWhitePoint.
It is only valid when W is a UnitWhitePoint.
Sourceimpl<T, W> Luv<T, W>where
T: FreeChannelScalar,
W: WhitePoint<T>,
impl<T, W> Luv<T, W>where
T: FreeChannelScalar,
W: WhitePoint<T>,
Sourcepub fn new_with_whitepoint(L: T, u: T, v: T, white_point: W) -> Self
pub fn new_with_whitepoint(L: T, u: T, v: T, white_point: W) -> Self
Construct a new Luv value with a given white point and channels
Sourcepub fn color_cast<TOut>(&self) -> Luv<TOut, W>where
T: ChannelFormatCast<TOut>,
TOut: FreeChannelScalar,
pub fn color_cast<TOut>(&self) -> Luv<TOut, W>where
T: ChannelFormatCast<TOut>,
TOut: FreeChannelScalar,
Convert the internal channel scalar format
Sourcepub fn L_mut(&mut self) -> &mut T
pub fn L_mut(&mut self) -> &mut T
Returns a mutable reference to the L lightness channel scalar
Sourcepub fn u_mut(&mut self) -> &mut T
pub fn u_mut(&mut self) -> &mut T
Returns a mutable reference to the u green-red channel scalar
Sourcepub fn v_mut(&mut self) -> &mut T
pub fn v_mut(&mut self) -> &mut T
Returns a mutable reference to the v blue-yellow channel scalar
Sourcepub fn white_point(&self) -> &W
pub fn white_point(&self) -> &W
Returns a reference to the white point for the Lab color space
Sourceimpl<T, W> Luv<T, W>
impl<T, W> Luv<T, W>
Sourcepub fn from_xyz(from: &Xyz<T>, wp: W) -> Self
pub fn from_xyz(from: &Xyz<T>, wp: W) -> Self
Construct a Luv value from an Xyz value and white point
Sourcepub fn epsilon() -> T
pub fn epsilon() -> T
Return the $\epsilon$ constant used in the Lab conversion
For a description of the value, visit BruceLindbloom.com.
Sourcepub fn kappa() -> T
pub fn kappa() -> T
Return the $\kappa$ constant used in the Lab conversion
For a description of the value, visit BruceLindbloom.com.