#[repr(C)]pub struct Rgb<T> { /* private fields */ }Expand description
The Rgb device-dependent cartesian color model.
Rgb<T> has three primaries: red, green blue, which are always positive and in the normalized
range [0, 1]. Rgb<T> accepts both integer and float components.
It is made to be efficient and easy to use in many different applications, and can be
transmuted directly to a &[T; N].
Rgb is the base device dependent color space from which all others go through to convert,
which can be converted to the other
device dependent spaces or to the device independent CIE spaces directly. The color space
of Rgb is not specified or assumed, it is up to you to not mix color spaces improperly or use
an appropriate wrapper.
Examples:
use prisma::{Broadcast, HomogeneousColor, Lerp, Rgb};
let black = Rgb::broadcast(0.0f32);
let blue = Rgb::new(0, 0, 255u8);
// Convert blue to have float channels and compute the color halfway between blue and black
let blended = black.lerp(&blue.color_cast(), 0.5);
assert_eq!(blended, Rgb::new(0.0, 0.0, 0.5));Implementations
Sourceimpl<T> Rgb<T>where
T: PosNormalChannelScalar,
impl<T> Rgb<T>where
T: PosNormalChannelScalar,
Sourcepub fn new(red: T, green: T, blue: T) -> Self
pub fn new(red: T, green: T, blue: T) -> Self
Construct a new Rgb instance with the given channel values
Sourcepub fn color_cast<TOut>(&self) -> Rgb<TOut>where
T: ChannelFormatCast<TOut>,
TOut: PosNormalChannelScalar,
pub fn color_cast<TOut>(&self) -> Rgb<TOut>where
T: ChannelFormatCast<TOut>,
TOut: PosNormalChannelScalar,
Convert the internal channel scalar format
Sourceimpl<T> Rgb<T>where
T: PosNormalChannelScalar + Float,
impl<T> Rgb<T>where
T: PosNormalChannelScalar + Float,
Sourcepub fn chromaticity_coordinates(&self) -> ChromaticityCoordinates<T>
pub fn chromaticity_coordinates(&self) -> ChromaticityCoordinates<T>
Compute the ChromaticityCooridinates
for an Rgb instance